use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
AES
David
Don'ts
Fu
Golden
HMAC
Hukins
Liu
MAC's
Petr
Písař
Rekeying
Secure
Sereal
Session
Storage
Tom
al
authenticator
ciphertext
cryptographically
dagolden
decrypting
et
lib
login
ppisar
scalability
tom
unencrypted
